@@ -2,7 +2,7 @@
 """
 OnionShare | https://onionshare.org/
 
-Copyright (C) 2014 Micah Lee <micah@micahflee.com>
+Copyright (C) 2015 Micah Lee <micah@micahflee.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,15 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 import os, sys, inspect, platform
+from onionshare import helpers
+
 
 def get_onionshare_gui_dir():
-    if platform.system() == 'Darwin':
+    """
+    Returns the OnionShare gui directory.
+    """
+    p = helpers.get_platform()
+    if p == 'Darwin':
         onionshare_gui_dir = os.path.dirname(__file__)
     else:
         onionshare_gui_dir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
@@ -28,9 +34,16 @@ def get_onionshare_gui_dir():
 
 onionshare_gui_dir = get_onionshare_gui_dir()
 
+
 def get_image_path(filename):
-    if platform.system() == 'Linux':
+    """
+    Returns the OnionShare image path.
+    """
+    p = helpers.get_platform()
+    if p == 'Linux' or p == 'Tails':
         prefix = os.path.join(sys.prefix, 'share/onionshare/images')
+    elif p == 'Darwin':
+        prefix = os.path.join(helpers.osx_resources_dir, 'images')
     else:
         prefix = os.path.join(os.path.dirname(get_onionshare_gui_dir()), 'images')
     return os.path.join(prefix, filename)
