@@ -1,7 +1,7 @@
 """
 OnionShare | https://onionshare.org/
 
-Copyright (C) 2014 Micah Lee <micah@micahflee.com>
+Copyright (C) 2015 Micah Lee <micah@micahflee.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,13 +21,7 @@ from nose import with_setup
 
 import test_helpers
 
-def test_get_platform_on_tails():
-    "get_platform() returns 'Tails' when hostname is 'amnesia'"
-    helpers.platform.uname = lambda: ('Linux', 'amnesia', '3.14-1-amd64', '#1 SMP Debian 3.14.4-1 (2014-05-13)', 'x86_64', '')
-    assert helpers.get_platform() == 'Tails'
-
 def test_get_platform_returns_platform_system():
-    "get_platform() returns platform.system() when ONIONSHARE_PLATFORM is not defined"
+    """get_platform() returns platform.system() when ONIONSHARE_PLATFORM is not defined"""
     helpers.platform.system = lambda: 'Sega Saturn'
     assert helpers.get_platform() == 'Sega Saturn'
-
