@@ -2,7 +2,7 @@
 """
 OnionShare | https://onionshare.org/
 
-Copyright (C) 2014 Micah Lee <micah@micahflee.com>
+Copyright (C) 2015 Micah Lee <micah@micahflee.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,19 +21,21 @@ import locale
 from onionshare import strings
 from nose import with_setup
 
+
 def test_starts_with_empty_strings():
-    "creates an empty strings dict by default"
+    """creates an empty strings dict by default"""
     assert strings.strings == {}
 
+
 def test_load_strings_defaults_to_english():
-    "load_strings() loads English by default"
+    """load_strings() loads English by default"""
     locale.getdefaultlocale = lambda: ('en_US', 'UTF-8')
     strings.load_strings()
     assert strings._('wait_for_hs') == "Waiting for HS to be ready:"
 
+
 def test_load_strings_loads_other_languages():
-    "load_strings() loads other languages in different locales"
+    """load_strings() loads other languages in different locales"""
     locale.getdefaultlocale = lambda: ('fr_FR', 'UTF-8')
     strings.load_strings("fr")
     assert strings._('wait_for_hs') == "En attente du HS:"
-
