@@ -1,7 +1,7 @@
 """
 OnionShare | https://onionshare.org/
 
-Copyright (C) 2014 Micah Lee <micah@micahflee.com>
+Copyright (C) 2015 Micah Lee <micah@micahflee.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,14 +20,16 @@ import socket
 from onionshare import OnionShare
 from nose import with_setup
 
+
 def test_choose_port_returns_a_port_number():
-    "choose_port() returns a port number"
+    """choose_port() returns a port number"""
     app = OnionShare()
     app.choose_port()
-    assert  1024 <= app.port <= 65535
+    assert 1024 <= app.port <= 65535
+
 
 def test_choose_port_returns_an_open_port():
-    "choose_port() returns an open port"
+    """choose_port() returns an open port"""
     app = OnionShare()
     # choose a new port
     app.choose_port()
